@@ -24,6 +24,11 @@ NULL
 #'
 #' @export
 registerDoSpark <- function(spark_conn, parallelism = NULL, ...) {
+
+  if (packageVersion("dbplyr") < "2") {
+    stop("This feature is only supported by dbplyr 2.0 or above")
+  }
+
   do_spark_parallelism <- as.integer(
     parallelism %||%
       tryCatch(
