@@ -1,3 +1,6 @@
+#' @include ml_clustering.R
+NULL
+
 #' @rdname ml_gradient_boosted_trees
 #' @template roxlate-ml-probabilistic-classifier-params
 #' @export
@@ -68,8 +71,7 @@ ml_gbt_classifier.spark_connection <- function(x, formula = NULL, max_iter = 20,
         probability_col = .args[["probability_col"]],
         raw_prediction_col = .args[["raw_prediction_col"]]
       )
-    }
-  ) %>% (
+    }) %>% (
     function(obj) {
       do.call(
         invoke,
